shithub: pokecrystal

Download patch

ref: 7c862ca7e21d0223a5158f3689bfc81755ab06c1
parent: c07ed74a5dbdf7ce684ec02b546862bbcc582f5f
author: yenatch <yenatch@gmail.com>
date: Tue Feb 10 10:32:30 EST 2015

Blind wram part 5.

starting to go smoothly

--- a/event/name_rater.asm
+++ b/event/name_rater.asm
@@ -22,7 +22,7 @@
 	xor a
 	ld [MonType], a
 	ld a, [CurPartySpecies]
-	ld [$d265], a
+	ld [wd265], a
 	ld [CurSpecies], a
 	call GetBaseData
 	ld b, 0
--- a/items/item_descriptions.asm
+++ b/items/item_descriptions.asm
@@ -9,7 +9,7 @@
 	push de
 	callba GetTMHMItemMove
 	pop hl
-	ld a, [$d265]
+	ld a, [wd265]
 	ld [CurSpecies], a
 	predef PrintMoveDesc
 	ret
--- a/items/item_effects.asm
+++ b/items/item_effects.asm
@@ -1,10 +1,10 @@
 _DoItemEffect:: ; e722
 	ld a, [CurItem]
-	ld [$d265], a
+	ld [wd265], a
 	call GetItemName
 	call CopyName1
 	ld a, 1
-	ld [$d0ec], a
+	ld [wd0ec], a
 	ld a, [CurItem]
 	dec a
 	ld hl, ItemEffects
@@ -225,7 +225,7 @@
 
 .asm_e8c0
 	xor a
-	ld [$c64e], a
+	ld [wc64e], a
 	ld a, [CurItem]
 	cp PARK_BALL
 	call nz, Functionedfa
@@ -392,7 +392,7 @@
 	ld a, [EnemyMonSpecies]
 
 .asm_e99f
-	ld [$c64e], a
+	ld [wc64e], a
 	ld c, 20
 	call DelayFrames
 
@@ -401,7 +401,7 @@
 	jr c, .asm_e9b0
 	ld a, POKE_BALL
 .asm_e9b0
-	ld [$c689], a
+	ld [wc689], a
 
 	ld de, ANIM_THROW_POKE_BALL
 	ld a, e
@@ -411,10 +411,10 @@
 	xor a
 	ld [hBattleTurn], a
 	ld [Buffer2], a
-	ld [$cfca], a
+	ld [wcfca], a
 	predef PlayBattleAnim
 
-	ld a, [$c64e]
+	ld a, [wc64e]
 	and a
 	jr nz, .asm_e9f5
 	ld a, [Buffer2]
@@ -460,7 +460,7 @@
 
 .asm_ea1a
 	set 3, [hl]
-	ld hl, $c6f2
+	ld hl, wc6f2
 	ld a, [EnemyMonDVs]
 	ld [hli], a
 	ld a, [EnemyMonDVs + 1]
@@ -491,12 +491,12 @@
 	ld hl, EnemySubStatus5
 	bit SUBSTATUS_TRANSFORMED, [hl]
 	jr nz, .asm_ea67
-	ld hl, $c735
+	ld hl, wc735
 	ld de, EnemyMonMoves
 	ld bc, NUM_MOVES
 	call CopyBytes
 
-	ld hl, $c739
+	ld hl, wc739
 	ld de, EnemyMonPP
 	ld bc, NUM_MOVES
 	call CopyBytes
@@ -503,9 +503,9 @@
 .asm_ea67
 
 	ld a, [EnemyMonSpecies]
-	ld [$c64e], a
+	ld [wc64e], a
 	ld [CurPartySpecies], a
-	ld [$d265], a
+	ld [wd265], a
 	ld a, [BattleType]
 	cp BATTLETYPE_TUTORIAL
 	jp z, .asm_ebd9
@@ -517,13 +517,13 @@
 
 	call ClearSprites
 
-	ld a, [$d265]
+	ld a, [wd265]
 	dec a
 	call CheckCaughtMon
 
 	ld a, c
 	push af
-	ld a, [$d265]
+	ld a, [wd265]
 	dec a
 	call SetSeenAndCaughtMon
 	pop af
@@ -539,7 +539,7 @@
 	call ClearSprites
 
 	ld a, [EnemyMonSpecies]
-	ld [$d265], a
+	ld [wd265], a
 	predef Functionfb877
 
 .asm_eab7
@@ -548,7 +548,7 @@
 	jp z, .asm_ebd1
 	cp BATTLETYPE_CELEBI
 	jr nz, .asm_eac8
-	ld hl, $d0ee
+	ld hl, wd0ee
 	set 6, [hl]
 .asm_eac8
 
@@ -582,7 +582,7 @@
 	call PrintText
 
 	ld a, [CurPartySpecies]
-	ld [$d265], a
+	ld [wd265], a
 	call GetPokemonName
 
 	call YesNoBox
@@ -626,7 +626,7 @@
 	ld a, [$ad10]
 	cp MONS_PER_BOX
 	jr nz, .asm_eb5b
-	ld hl, $d0ee
+	ld hl, wd0ee
 	set 7, [hl]
 
 .asm_eb5b
@@ -643,7 +643,7 @@
 	call PrintText
 
 	ld a, [CurPartySpecies]
-	ld [$d265], a
+	ld [wd265], a
 	call GetPokemonName
 
 	call YesNoBox
@@ -653,7 +653,7 @@
 	ld [CurPartyMon], a
 	ld a, BOXMON
 	ld [MonType], a
-	ld de, $d050
+	ld de, wd050
 	ld b, $0
 	callba Function116c1
 
@@ -660,7 +660,7 @@
 	ld a, $1
 	call GetSRAMBank
 
-	ld hl, $d050
+	ld hl, wd050
 	ld de, $b082
 	ld bc, $000b
 	call CopyBytes
@@ -676,7 +676,7 @@
 	call GetSRAMBank
 
 	ld hl, $b082
-	ld de, $d050
+	ld de, wd050
 	ld bc, $000b
 	call CopyBytes
 
@@ -709,7 +709,7 @@
 	cp BATTLETYPE_CONTEST
 	jr z, .used_park_ball
 
-	ld a, [$c64e]
+	ld a, [wc64e]
 	and a
 	jr z, .toss
 
@@ -719,11 +719,11 @@
 .toss
 	ld hl, NumItems
 	inc a
-	ld [$d10c], a
+	ld [wd10c], a
 	jp TossItem
 
 .used_park_ball
-	ld hl, $dc79
+	ld hl, wdc79
 	dec [hl]
 	ret
 ; ec0a
@@ -1201,10 +1201,10 @@
 	jr z, .asm_ee35
 
 	ld a, $1
-	ld [$d1e9], a
+	ld [wd1e9], a
 	callba Function421d8
 
-	ld a, [$d268]
+	ld a, [wd268]
 	and a
 	jr z, .asm_ee35
 
@@ -1215,7 +1215,7 @@
 
 .asm_ee38
 	xor a
-	ld [$d0ec], a
+	ld [wd0ec], a
 	ret
 ; ee3d
 
@@ -1288,7 +1288,7 @@
 
 Functionee9f: ; ee9f
 	xor a
-	ld [$d0ec], a
+	ld [wd0ec], a
 	jp ClearPalettes
 ; eea6
 
@@ -1344,7 +1344,7 @@
 Functioneef5: ; eef5
 	ld a, [CurPartySpecies]
 	ld [CurSpecies], a
-	ld [$d265], a
+	ld [wd265], a
 	ld a, PartyMon1Level - PartyMon1
 	call GetPartyParamLocation
 	ld a, [hl]
@@ -1438,11 +1438,11 @@
 	xor a
 	ld [MonType], a
 	ld a, [CurPartySpecies]
-	ld [$d265], a
+	ld [wd265], a
 	predef LearnLevelMoves
 
 	xor a
-	ld [$d1e9], a
+	ld [wd1e9], a
 	callba Function421d8
 
 	jp Functionf795
@@ -1511,7 +1511,7 @@
 	xor a
 	ld [hl], a
 	ld a, b
-	ld [PartyMenuActionText], a ; $d141
+	ld [PartyMenuActionText], a
 	call Functionf030
 	call Functionf780
 	call Functionf279
@@ -1522,7 +1522,7 @@
 Functionf009: ; f009 (3:7009)
 	call Functionf2a6
 	jr nc, .asm_f01c
-	ld a, [PlayerSubStatus3] ; $c66a
+	ld a, [PlayerSubStatus3]
 	bit 7, a
 	jr z, .asm_f01c
 	ld a, c
@@ -1540,9 +1540,9 @@
 	ld a, $22
 	call GetPartyParamLocation
 	ld a, [hli]
-	ld [BattleMonHP], a ; $c63c
+	ld [BattleMonHP], a
 	ld a, [hld]
-	ld [$c63d], a
+	ld [BattleMonHP + 1], a
 	ret
 
 Functionf030: ; f030 (3:7030)
@@ -1549,16 +1549,16 @@
 	call Functionf2a6
 	ret nc
 	xor a
-	ld [BattleMonStatus], a ; $c63a
-	ld hl, PlayerSubStatus5 ; $c66c
+	ld [BattleMonStatus], a
+	ld hl, PlayerSubStatus5
 	res 0, [hl]
-	ld hl, PlayerSubStatus1 ; $c668
+	ld hl, PlayerSubStatus1
 	res 0, [hl]
 	call Functionf058
 	ld a, c
 	cp $ff
 	jr nz, .asm_f04f
-	ld hl, PlayerSubStatus3 ; $c66a
+	ld hl, PlayerSubStatus3
 	res 7, [hl]
 .asm_f04f
 	push bc
@@ -1568,7 +1568,7 @@
 
 Functionf058: ; f058 (3:7058)
 	push hl
-	ld a, [CurItem] ; $d106
+	ld a, [CurItem]
 	ld hl, Table_f071
 	ld bc, 3
 .next
@@ -1659,7 +1659,7 @@
 	ld a, [CurPartyMon]
 	ld c, a
 	ld d, 0
-	ld hl, $c6fc
+	ld hl, wc6fc
 	ld b, CHECK_FLAG
 	predef FlagPredef
 	ld a, c
@@ -1668,7 +1668,7 @@
 
 	ld a, [CurPartyMon]
 	ld c, a
-	ld hl, $c664
+	ld hl, wc664
 	ld b, SET_FLAG
 	predef FlagPredef
 
@@ -1814,13 +1814,13 @@
 	ret nc
 
 	xor a
-	ld [Danger], a ; $c2a6
+	ld [Danger], a
 	call Functionf395
 	call Functionf2d1
 	call Functionf01e
 	call Functionf1db
 	ld a, $f5
-	ld [PartyMenuActionText], a ; $d141
+	ld [PartyMenuActionText], a
 	call Functionf279
 	call Functionf795
 	ld a, 0
@@ -1831,12 +1831,12 @@
 	ld de, SFX_POTION
 	call WaitPlaySFX
 	pop de
-	ld a, [CurPartyMon] ; $d109
+	ld a, [CurPartyMon]
 	hlcoord 11, 0
 	ld bc, SCREEN_WIDTH * 2
 	call AddNTimes
 	ld a, $2
-	ld [$d10a], a
+	ld [wd10a], a
 	predef_jump Functionc6e0
 
 Functionf1f9: ; f1f9 (3:71f9)
@@ -1843,7 +1843,7 @@
 	call Functionf20b
 	ret c
 
-	ld a, [CurPartySpecies] ; $d108
+	ld a, [CurPartySpecies]
 	cp EGG
 	jr nz, .asm_f209
 
@@ -1857,7 +1857,7 @@
 
 Functionf20b: ; f20b (3:720b)
 	ld a, b
-	ld [PartyMenuActionText], a ; $d141
+	ld [PartyMenuActionText], a
 	push hl
 	push de
 	push bc
@@ -1881,10 +1881,10 @@
 	ret
 
 Functionf24a: ; f24a (3:724a)
-	ld [PartyMenuActionText], a ; $d141
-	ld a, [CurPartySpecies] ; $d108
+	ld [PartyMenuActionText], a
+	ld a, [CurPartySpecies]
 	push af
-	ld a, [CurPartyMon] ; $d109
+	ld a, [CurPartyMon]
 	push af
 	push hl
 	push de
@@ -1898,22 +1898,22 @@
 	pop de
 	pop hl
 	pop af
-	ld [CurPartyMon], a ; $d109
+	ld [CurPartyMon], a
 	pop af
-	ld [CurPartySpecies], a ; $d108
+	ld [CurPartySpecies], a
 	ret
 
 Functionf279: ; f279 (3:7279)
 	xor a
-	ld [hBGMapMode], a ; $ff00+$d4
-	ld hl, TileMap ; $c4a0 (aliases: SpritesEnd)
+	ld [hBGMapMode], a
+	ld hl, TileMap
 	ld bc, TileMapEnd - TileMap
 	ld a, " "
 	call ByteFill
-	ld a, [PartyMenuActionText] ; $d141
+	ld a, [PartyMenuActionText]
 	call Functionf24a
 	ld a, $1
-	ld [hBGMapMode], a ; $ff00+$d4
+	ld [hBGMapMode], a
 	ld c, $32
 	call DelayFrames
 	jp Functiona80
@@ -1924,7 +1924,7 @@
 
 Functionf29e: ; f29e (3:729e)
 	xor a
-	ld [$d0ec], a
+	ld [wd0ec], a
 
 Functionf2a2: ; f2a2 (3:72a2)
 	call ClearPalettes
@@ -1931,12 +1931,12 @@
 	ret
 
 Functionf2a6: ; f2a6 (3:72a6)
-	ld a, [IsInBattle] ; $d22d (aliases: EnemyMonEnd)
+	ld a, [IsInBattle]
 	and a
 	ret z
-	ld a, [CurPartyMon] ; $d109
+	ld a, [CurPartyMon]
 	push hl
-	ld hl, CurBattleMon ; $d0d4
+	ld hl, CurBattleMon
 	cp [hl]
 	pop hl
 	jr nz, .asm_f2b8
@@ -2033,24 +2033,24 @@
 	ld a, $22
 	call GetPartyParamLocation
 	ld a, [hli]
-	ld [$d1ef], a
+	ld [wd1ef], a
 	ld a, [hl]
-	ld [$d1ee], a
+	ld [wd1ee], a
 	ret
 ; f336 (3:7336)
 
 Functionf336: ; f336
 	ld a, d
-	ld [$d1ef], a
+	ld [wd1ef], a
 	ld a, e
-	ld [$d1ee], a
+	ld [wd1ee], a
 	ret
 ; f33f
 
 Functionf33f: ; f33f
-	ld a, [$d1ef]
+	ld a, [wd1ef]
 	ld d, a
-	ld a, [$d1ee]
+	ld a, [wd1ee]
 	ld e, a
 	ret
 ; f348
@@ -2059,15 +2059,15 @@
 	ld a, $22
 	call GetPartyParamLocation
 	ld a, [hli]
-	ld [$d1ed], a
+	ld [wd1ed], a
 	ld a, [hl]
-	ld [$d1ec], a
+	ld [wd1ec], a
 	ret
 
 Functionf356: ; f356 (3:7356)
-	ld a, [$d1ed]
+	ld a, [wd1ed]
 	ld d, a
-	ld a, [$d1ec]
+	ld a, [wd1ec]
 	ld e, a
 	ret
 
@@ -2076,16 +2076,16 @@
 	ld a, $24
 	call GetPartyParamLocation
 	ld a, [hli]
-	ld [Buffer2], a ; $d1eb (aliases: MovementType)
+	ld [Buffer2], a
 	ld a, [hl]
-	ld [Buffer1], a ; $d1ea (aliases: MagikarpLength)
+	ld [Buffer1], a
 	pop hl
 	ret
 
 Functionf36f: ; f36f (3:736f)
-	ld a, [Buffer2] ; $d1eb (aliases: MovementType)
+	ld a, [Buffer2]
 	ld d, a
-	ld a, [Buffer1] ; $d1ea (aliases: MagikarpLength)
+	ld a, [Buffer1]
 	ld e, a
 	ret
 
@@ -2110,7 +2110,7 @@
 
 Functionf395: ; f395 (3:7395)
 	push hl
-	ld a, [CurItem] ; $d106
+	ld a, [CurItem]
 	ld hl, Tablef3af
 	ld d, a
 .next
@@ -2154,13 +2154,13 @@
 
 Functionf3df: ; f3df (3:73df)
 ; Softboiled/Milk Drink in the field
-	ld a, [$d0d8]
+	ld a, [wd0d8]
 	dec a
 	ld b, a
 	call Functionf419
 	jr c, .asm_f413
 	ld a, b
-	ld [CurPartyMon], a ; $d109
+	ld [CurPartyMon], a
 	call Functionf30d
 	call Functionf378
 	call Functionf2f9
@@ -2169,7 +2169,7 @@
 	pop bc
 	call Functionf378
 	ld a, c
-	ld [CurPartyMon], a ; $d109
+	ld [CurPartyMon], a
 	call Functionf30d
 	call Functionf2d1
 	call Functionf1db
@@ -2179,17 +2179,17 @@
 .asm_f413
 	ld a, b
 	inc a
-	ld [$d0d8], a
+	ld [wd0d8], a
 	ret
 
 Functionf419: ; f419 (3:7419)
 	push bc
 	ld a, $1
-	ld [PartyMenuActionText], a ; $d141
+	ld [PartyMenuActionText], a
 	call Functionf21c
 	pop bc
 	jr c, .asm_f43e
-	ld a, [$d0d8]
+	ld a, [wd0d8]
 	dec a
 	ld c, a
 	ld a, b
@@ -2196,7 +2196,7 @@
 	cp c
 	jr z, .asm_f440
 	ld a, c
-	ld [CurPartyMon], a ; $d109
+	ld [CurPartyMon], a
 	call Functionf30d
 	jr z, .asm_f440
 	call Functionf31b
@@ -2223,10 +2223,10 @@
 
 EscapeRope: ; f44f
 	xor a
-	ld [$d0ec], a
+	ld [wd0ec], a
 	callba Functioncb95
 
-	ld a, [$d0ec]
+	ld a, [wd0ec]
 	cp 1
 	call z, Functionf795
 	ret
@@ -2248,12 +2248,12 @@
 ; f46c
 
 Function_0xf46c: ; f46c
-	ld a, [$dca1]
+	ld a, [wdca1]
 	and a
 	ld hl, UnknownText_0xf47d
 	jp nz, PrintText
 	ld a, b
-	ld [$dca1], a
+	ld [wdca1], a
 	jp Functionf789
 ; f47d
 
@@ -2278,16 +2278,16 @@
 	dec a
 	jr nz, .asm_f4a6
 	inc a
-	ld [$d232], a
-	ld a, [$d0ee]
+	ld [wd232], a
+	ld a, [wd0ee]
 	and $c0
 	or $2
-	ld [$d0ee], a
+	ld [wd0ee], a
 	jp Functionf789
 
 .asm_f4a6
 	xor a
-	ld [$d0ec], a
+	ld [wd0ec], a
 	ret
 ; f4ab
 
@@ -2332,7 +2332,7 @@
 	xor a
 	ld [hBattleTurn], a
 	ld [AttackMissed], a
-	ld [$c70d], a
+	ld [EffectFailed], a
 	callba Function361ef
 	call WaitSFX
 
@@ -2361,7 +2361,7 @@
 .asm_f512
 
 	xor a
-	ld [$d002], a
+	ld [wd002], a
 
 	ld b, $ff ^ SLP
 
@@ -2384,7 +2384,7 @@
 	and b
 	ld [hl], a
 
-	ld a, [$d002]
+	ld a, [wd002]
 	and a
 	ld hl, UnknownText_0xf56c
 	jp z, PrintText
@@ -2409,7 +2409,7 @@
 	and SLP
 	jr z, .asm_f564
 	ld a, 1
-	ld [$d002], a
+	ld [wd002], a
 .asm_f564
 	pop af
 	and b
@@ -2510,7 +2510,7 @@
 Elixer:
 Mysteryberry: ; f5bf
 	ld a, [CurItem]
-	ld [$d002], a
+	ld [wd002], a
 
 .asm_f5c5
 	ld b, $1
@@ -2518,7 +2518,7 @@
 	jp c, Functionf6e0
 
 .asm_f5cd
-	ld a, [$d002]
+	ld a, [wd002]
 	cp MAX_ELIXER
 	jp z, Functionf6af
 	cp ELIXER
@@ -2525,7 +2525,7 @@
 	jp z, Functionf6af
 
 	ld hl, UnknownText_0xf725
-	ld a, [$d002]
+	ld a, [wd002]
 	cp PP_UP
 	jr z, .asm_f5e7
 	ld hl, UnknownText_0xf72a
@@ -2538,7 +2538,7 @@
 	xor a
 	ld [CurMoveNum], a
 	ld a, $2
-	ld [$d235], a
+	ld [wd235], a
 	callba Function3e4bc
 
 	pop bc
@@ -2551,12 +2551,12 @@
 
 	push hl
 	ld a, [hl]
-	ld [$d265], a
+	ld [wd265], a
 	call GetMoveName
 	call CopyName1
 
 	pop hl
-	ld a, [$d002]
+	ld a, [wd002]
 	cp PP_UP
 	jp nz, Functionf6a7
 
@@ -2580,7 +2580,7 @@
 	add $40
 	ld [hl], a
 	ld a, $1
-	ld [$d265], a
+	ld [wd265], a
 	call Functionf84c
 	call Functionf780
 
@@ -2657,7 +2657,7 @@
 
 Functionf6af: ; f6af
 	xor a
-	ld hl, $cfa9
+	ld hl, wcfa9
 	ld [hli], a
 	ld [hl], a
 	ld b, NUM_MOVES
@@ -2672,16 +2672,16 @@
 
 	call Functionf6e8
 	jr z, .asm_f6ce
-	ld hl, $cfaa
+	ld hl, wcfaa
 	inc [hl]
 
 .asm_f6ce
-	ld hl, $cfa9
+	ld hl, wcfa9
 	inc [hl]
 	pop bc
 	dec b
 	jr nz, .asm_f6b7
-	ld a, [$cfaa]
+	ld a, [wcfaa]
 	and a
 	jp nz, Functionf652
 
@@ -2691,7 +2691,7 @@
 Functionf6e0: ; f6e0
 	call ClearPalettes
 	xor a
-	ld [$d0ec], a
+	ld [wd0ec], a
 	ret
 ; f6e8
 
@@ -2702,7 +2702,7 @@
 	ld hl, PartyMon1PP
 	ld bc, PartyMon2 - PartyMon1
 	call Functionf963
-	ld a, [$d265]
+	ld a, [wd265]
 	ld b, a
 	ld a, [hl]
 	and $3f
@@ -2709,7 +2709,7 @@
 	cp b
 	jr nc, .asm_f723
 
-	ld a, [$d002]
+	ld a, [wd002]
 	cp MAX_ELIXER
 	jr z, .asm_f71d
 	cp MAX_ETHER
@@ -2792,7 +2792,7 @@
 
 SacredAsh: ; f753
 	callba _SacredAsh
-	ld a, [$d0ec]
+	ld a, [wd0ec]
 	cp $1
 	ret nz
 	call Functionf795
@@ -2937,7 +2937,7 @@
 Functionf795: ; f795
 	ld hl, NumItems
 	ld a, 1
-	ld [$d10c], a
+	ld [wd10c], a
 	jp TossItem
 ; f7a0
 
@@ -2949,9 +2949,9 @@
 	ld a, d
 	ld [FXAnimIDHi], a
 	xor a
-	ld [$c689], a
+	ld [wc689], a
 	ld [hBattleTurn], a
-	ld [$cfca], a
+	ld [wcfca], a
 	predef PlayBattleAnim
 	ld hl, BlockedTheBallText
 	call PrintText
@@ -2966,7 +2966,7 @@
 
 	; Item wasn't used.
 	ld a, $2
-	ld [$d0ec], a
+	ld [wd0ec], a
 	ret
 ; f7d6
 
@@ -2981,7 +2981,7 @@
 
 	; Item wasn't used.
 	ld a, $2
-	ld [$d0ec], a
+	ld [wd0ec], a
 	ret
 ; f7e8
 
@@ -3011,7 +3011,7 @@
 CantUseItemMessage: ; f804
 ; Item couldn't be used.
 	xor a
-	ld [$d0ec], a
+	ld [wd0ec], a
 	jp PrintText
 ; f80b
 
@@ -3110,10 +3110,10 @@
 	ld a, b
 	cp NUM_MOVES + 1
 	ret z
-	ld a, [$d265]
+	ld a, [wd265]
 	dec a
 	jr nz, .asm_f876
-	ld a, [$cfa9]
+	ld a, [wcfa9]
 	inc a
 	cp b
 	jr nz, .asm_f87d
@@ -3162,7 +3162,7 @@
 .asm_f8ab
 	add b
 	ld b, a
-	ld a, [$d265]
+	ld a, [wd265]
 	dec a
 	jr z, .asm_f8b6
 	dec c
@@ -3182,7 +3182,7 @@
 	call GetPartyParamLocation
 	pop de
 	xor a
-	ld [$cfa9], a
+	ld [wcfa9], a
 	ld [MonType], a
 	ld c, NUM_MOVES
 .loop
@@ -3198,11 +3198,11 @@
 	ld a, [de]
 	and $c0
 	ld b, a
-	ld a, [$d265]
+	ld a, [wd265]
 	add b
 	ld [de], a
 	inc de
-	ld hl, $cfa9
+	ld hl, wcfa9
 	inc [hl]
 	pop hl
 	dec c
@@ -3273,15 +3273,15 @@
 	pop bc
 
 	or b
-	ld hl, $d074
+	ld hl, StringBuffer1 + 1
 	ld [hl], a
 	xor a
-	ld [$d265], a
+	ld [wd265], a
 	ld a, b
 	call Functionf881
 	ld a, [hl]
 	and $3f
-	ld [$d265], a
+	ld [wd265], a
 
 	pop af
 	ld [StringBuffer1 + 1], a
@@ -3295,7 +3295,7 @@
 	call AddNTimes
 
 Functionf969: ; f969
-	ld a, [$cfa9]
+	ld a, [wcfa9]
 	ld c, a
 	ld b, 0
 	add hl, bc
--- a/text/battle.asm
+++ b/text/battle.asm
@@ -1,7 +1,7 @@
 BattleText_0x80730: ; 0x80730
 	text $52, " picked up"
 	line "¥@"
-	deciram $c6ec, $36
+	deciram wPayDayMoney, $36
 	text "!"
 	prompt
 ; 0x80746
@@ -8,8 +8,8 @@
 
 WildPokemonAppearedText: ; 0x80746
 	text "Wild @"
-	text_from_ram $c616
-	db $0
+	text_from_ram EnemyMonNick
+	text ""
 	line "appeared!"
 	prompt
 ; 0x8075c
@@ -17,7 +17,7 @@
 HookedPokemonAttackedText: ; 0x8075c
 	text "The hooked"
 	line "@"
-	text_from_ram $c616
+	text_from_ram EnemyMonNick
 	text $55
 	db "attacked!"
 	prompt
@@ -24,7 +24,7 @@
 ; 0x80778
 
 PokemonFellFromTreeText: ; 0x80778
-	text_from_ram $c616
+	text_from_ram EnemyMonNick
 	text " fell"
 	line "out of the tree!"
 	prompt
@@ -32,8 +32,8 @@
 
 WildCelebiAppearedText: ; 0x80793
 	text "Wild @"
-	text_from_ram $c616
-	db $0
+	text_from_ram EnemyMonNick
+	text ""
 	line "appeared!"
 	prompt
 ; 0x807a9
@@ -46,8 +46,8 @@
 
 BattleText_0x807bd: ; 0x807bd
 	text "Wild @"
-	text_from_ram $c616
-	db $0
+	text_from_ram EnemyMonNick
+	text ""
 	line "fled!"
 	prompt
 ; 0x807cf
@@ -54,8 +54,8 @@
 
 BattleText_0x807cf: ; 0x807cf
 	text "Enemy @"
-	text_from_ram $c616
-	db $0
+	text_from_ram EnemyMonNick
+	text ""
 	line "fled!"
 	prompt
 ; 0x807e2
@@ -99,7 +99,7 @@
 PerishCountText: ; 0x80864
 	text $5a, "'s"
 	line "PERISH count is @"
-	deciram $d265, $11
+	deciram wd265, $11
 	text "!"
 	prompt
 ; 0x80880
@@ -186,8 +186,8 @@
 
 BattleText_0x809a8: ; 0x809a8
 	text "Enemy @"
-	text_from_ram $c616
-	db $0
+	text_from_ram EnemyMonNick
+	text ""
 	line "fainted!"
 	prompt
 ; 0x809be
@@ -194,8 +194,8 @@
 
 BattleText_0x809be: ; 0x809be
 	text $52, " got ¥@"
-	deciram $c686, $36
-	db $0
+	deciram wc686, $36
+	text ""
 	line "for winning!"
 	prompt
 ; 0x809da
@@ -214,8 +214,8 @@
 
 BattleText_0x809fc: ; 0x809fc
 	text $52, " got ¥@"
-	deciram $c686, $36
-	db $0
+	deciram wc686, $36
+	text ""
 	line "for winning!"
 	cont "Sent some to MOM!"
 	prompt
@@ -239,8 +239,8 @@
 ; 0x80a75
 
 BattleText_0x80a75: ; 0x80a75
-	text_from_ram $c621
-	db $0
+	text_from_ram BattleMonNick
+	text ""
 	line "fainted!"
 	prompt
 ; 0x80a83
@@ -267,7 +267,7 @@
 	text $3f
 	line "is about to use"
 	cont "@"
-	text_from_ram $c616
+	text_from_ram EnemyMonNick
 	text "."
 
 	para "Will ", $52
@@ -279,7 +279,7 @@
 	text $3f
 	line "sent out"
 	cont "@"
-	text_from_ram $c616
+	text_from_ram EnemyMonNick
 	text "!"
 	done
 ; 0x80b0b
@@ -358,15 +358,15 @@
 ; 0x80c0d
 
 BattleText_0x80c0d: ; 0x80c0d
-	text_from_ram $c621
-	db $0
+	text_from_ram BattleMonNick
+	text ""
 	line "is already out."
 	prompt
 ; 0x80c22
 
 BattleText_0x80c22: ; 0x80c22
-	text_from_ram $c621
-	db $0
+	text_from_ram BattleMonNick
+	text ""
 	line "can't be recalled!"
 	prompt
 ; 0x80c39
@@ -384,8 +384,8 @@
 ; 0x80c72
 
 BattleText_0x80c72: ; 0x80c72
-	text_from_ram $c621
-	db $0
+	text_from_ram BattleMonNick
+	text ""
 	line "has no moves left!"
 	done
 ; 0x80c8a
@@ -398,22 +398,22 @@
 
 BattleText_0x80c9c: ; 0x80c9c
 	text_from_ram StringBuffer1
-	db $0, " grew to", $4f
-	db "level @"
-	deciram $d143, $13
-	db $0, "!@"
+	text " grew to"
+	line "level @"
+	deciram CurPartyLevel, $13
+	text "!@"
 	sound0
-	db $50
+	db "@"
 ; 0x80cb9
 
 BattleText_0x80cb9: ; 0x80cb9
-	db $50
+	db "@"
 ; 0x80cba
 
 BattleText_0x80cba: ; 0x80cba
 	text "Wild @"
-	text_from_ram $c616
-	db $0
+	text_from_ram EnemyMonNick
+	text ""
 	line "is eating!"
 	prompt
 ; 0x80cd1
@@ -420,8 +420,8 @@
 
 BattleText_0x80cd1: ; 0x80cd1
 	text "Wild @"
-	text_from_ram $c616
-	db $0
+	text_from_ram EnemyMonNick
+	text ""
 	line "is angry!"
 	prompt
 ; 0x80ce7
@@ -603,7 +603,7 @@
 ; 0x80f19
 
 LoafingAroundText: ; 0x80f19
-	text_from_ram $c621
+	text_from_ram BattleMonNick
 	text " is"
 	line "loafing around."
 	prompt
@@ -610,7 +610,7 @@
 ; 0x80f31
 
 BeganToNapText: ; 0x80f31
-	text_from_ram $c621
+	text_from_ram BattleMonNick
 	text " began"
 	line "to nap!"
 	prompt
@@ -617,7 +617,7 @@
 ; 0x80f44
 
 WontObeyText: ; 0x80f44
-	text_from_ram $c621
+	text_from_ram BattleMonNick
 	text " won't"
 	line "obey!"
 	prompt
@@ -624,7 +624,7 @@
 ; 0x80f54
 
 TurnedAwayText: ; 0x80f54
-	text_from_ram $c621
+	text_from_ram BattleMonNick
 	text " turned"
 	line "away!"
 	prompt
@@ -631,7 +631,7 @@
 ; 0x80f66
 
 IgnoredOrdersText: ; 0x80f66
-	text_from_ram $c621
+	text_from_ram BattleMonNick
 	text " ignored"
 	line "orders!"
 	prompt
@@ -638,7 +638,7 @@
 ; 0x80f7b
 
 IgnoredSleepingText: ; 0x80f7b
-	text_from_ram $c621
+	text_from_ram BattleMonNick
 	text " ignored"
 	line "orders…sleeping!"
 	prompt
@@ -654,7 +654,7 @@
 	text $5a
 	line "has no PP left for"
 	cont "@"
-	text_from_ram $d086
+	text_from_ram StringBuffer2
 	text "!"
 	prompt
 ; 0x80fd7
@@ -784,14 +784,15 @@
 	text_from_ram StringBuffer1
 	text " was"
 	cont "reduced by @"
-	deciram $d265, $11
+	deciram wd265, $11
 	text "!"
 	prompt
 ; 0x811a0
 
 BellChimedText: ; 0x811a0
-	db $0, "A bell chimed!", $4f
-	db $58
+	text "A bell chimed!"
+	line ""
+	prompt
 ; 0x811b1
 
 FellAsleepText: ; 0x811b1
@@ -857,7 +858,7 @@
 WontRiseAnymoreText: ; 0x81272
 	text $5a, "'s"
 	line "@"
-	text_from_ram $d086
+	text_from_ram StringBuffer2
 	text " won't"
 	cont "rise anymore!"
 	prompt
@@ -866,7 +867,7 @@
 WontDropAnymoreText: ; 0x8128f
 	text $59, "'s"
 	line "@"
-	text_from_ram $d086
+	text_from_ram StringBuffer2
 	text " won't"
 	cont "drop anymore!"
 	prompt
@@ -892,7 +893,7 @@
 
 PlayerHitTimesText: ; 0x812e5
 	text "Hit @"
-	deciram $c682, $11
+	deciram PlayerDamageTaken, $11
 	text " times!"
 	prompt
 ; 0x812f8
@@ -899,7 +900,7 @@
 
 EnemyHitTimesText: ; 0x812f8
 	text "Hit @"
-	deciram $c684, $11
+	deciram EnemyDamageTaken, $11
 	text " times!"
 	prompt
 ; 0x8130b
@@ -1207,7 +1208,7 @@
 
 MagnitudeText: ; 0x81751
 	text "Magnitude @"
-	deciram $d265, $11
+	deciram wd265, $11
 	text "!"
 	prompt
 ; 0x81764
--- a/tilesets/animations.asm
+++ b/tilesets/animations.asm
@@ -518,7 +518,7 @@
 	ld c, l
 
 ; Only during the Celebi event.
-	ld a, [$dbf3]
+	ld a, [wdbf3]
 	bit 2, a
 	jr nz, .asm_fc46c
 	ld hl, ForestTreeLeftFrames
@@ -560,7 +560,7 @@
 	ld c, l
 
 ; Only during the Celebi event.
-	ld a, [$dbf3]
+	ld a, [wdbf3]
 	bit 2, a
 	jr nz, .asm_fc4d4
 	ld hl, ForestTreeRightFrames
@@ -595,7 +595,7 @@
 	ld c, l
 
 ; Only during the Celebi event.
-	ld a, [$dbf3]
+	ld a, [wdbf3]
 	bit 2, a
 	jr nz, .asm_fc502
 	ld hl, ForestTreeLeftFrames
@@ -627,7 +627,7 @@
 	ld c, l
 
 ; Only during the Celebi event.
-	ld a, [$dbf3]
+	ld a, [wdbf3]
 	bit 2, a
 	jr nz, .asm_fc52c
 	ld hl, ForestTreeRightFrames
@@ -1009,7 +1009,7 @@
 	cp $e4
 	ret nz
 
-	ld a, [$d847]
+	ld a, [wd847]
 	cp $ff
 	ret nz
--- a/text/types.asm
+++ b/text/types.asm
@@ -79,9 +79,9 @@
 
 
 GetTypeName: ; 50964
 ; Copy the name of type [$d265] to StringBuffer1.
 
-	ld a, [$d265]
+	ld a, [wd265]
 	ld hl, TypeNames
 	ld e, a
 	ld d, 0
@@ -79,9 +79,9 @@
 
 GetTypeName: ; 50964
-; Copy the name of type [$d265] to StringBuffer1.
+; Copy the name of type [wd265] to StringBuffer1.
 